@@ -615,7 +615,7 @@ class Extractions(Core):
         for attr in attrs:
             obj = getattr(obj, attr)
         try:
-            if self.update_date is None:
+            if self.update_date is None or self.get_pandas_data_frame_path(feature_name) is None:
                 gitlab_data_list = obj(all=True)
             else:
                 gitlab_data_list = obj(all=True, since=self.update_date, updated_after=self.update_date, after=self.update_date)
@@ -716,8 +716,11 @@ class Extractions(Core):
         if parent_id is not None:
             if "MRs" in feature_name:
                 data["mr_iid"] = parent_id
+            elif "Commits" in feature_name:
+                data["commit_id"] = parent_id
             else:
                 data["parent_id"] = parent_id
+                print(f"{feature_name} has a unknown parent id!")
         for key, value in gitlab_data.items():
             if isinstance(value, dict):
                 if key == "commit" and "id" in value:
