@@ -4,29 +4,7 @@ import pandas as pd
 from gitlab2pandas.core import Core
 
 class Processing(Core):
-
-    def name_parent_ids(self):
-        """
-        Rename all parent_id column names to a suitable id name.
-
-        """
-        self.name_parent_id("parent_id", "commit_id", self.Features.COMMITS_REFS)
-        self.name_parent_id("parent_id", "commit_id", self.Features.COMMITS_DIFFS)
-
-    def name_parent_id(self, old_column, new_column, filename):
-        """
-        Rename a column name for a pandas file.
-        
-        """
-        df = self.get_pandas_data_frame(filename)
-        if df is not None and not df.empty and old_column in df:
-            if new_column in df:
-                df[new_column] = df[[old_column,new_column]].sum(1)
-                df.drop([old_column],1)
-            else:
-                df.rename(columns = {old_column:new_column}, inplace = True)
-            self.save_as_pandas(filename,df)
-    
+   
     def replace_user_id(self):
         """
         Replace user_ids with a pseudonym geneerated by human-id.
